# FindTheTail

Find The Tail is a procedure that is able to separate a given data set into subsets which belong to the body or the tail of an unknown underlying parent distribution. The data belonging to the tail are used to fit a generalized Pareto distribution as tail model.

## Documentation

The Documentation can be found ..

## Requirements
    - numpy
    - scipy
    - jinja2
    - matplotlib

## Installing

    pip install ftt
